@@ -92,6 +92,22 @@ class TestOperationModelFromService(unittest.TestCase):
                     },
                     'errors': [{'shape': 'NoSuchResourceException'}],
                     'documentation': 'Docs for OperationName',
+                    'authtype': 'v4'
+                },
+                'OperationTwo': {
+                    'http': {
+                        'method': 'POST',
+                        'requestUri': '/',
+                    },
+                    'name': 'OperationTwo',
+                    'input': {
+                        'shape': 'OperationNameRequest'
+                    },
+                    'output': {
+                        'shape': 'OperationNameResponse',
+                    },
+                    'errors': [{'shape': 'NoSuchResourceException'}],
+                    'documentation': 'Docs for OperationTwo',
                 }
             },
             'shapes': {
@@ -201,6 +217,146 @@ class TestOperationModelFromService(unittest.TestCase):
         self.assertEqual(
             operation.error_shapes[0].name, 'NoSuchResourceException')
 
+    def test_has_auth_type(self):
+        operation = self.service_model.operation_model('OperationName')
+        self.assertEqual(operation.auth_type, 'v4')
+
+    def test_auth_type_not_set(self):
+        operation = self.service_model.operation_model('OperationTwo')
+        self.assertIsNone(operation.auth_type)
+
+    def test_deprecated_present(self):
+        self.model['operations']['OperationName']['deprecated'] = True
+        service_model = model.ServiceModel(self.model)
+        operation_name = service_model.operation_model('OperationName')
+        self.assertTrue(operation_name.deprecated)
+
+    def test_deprecated_present_false(self):
+        self.model['operations']['OperationName']['deprecated'] = False
+        service_model = model.ServiceModel(self.model)
+        operation_name = service_model.operation_model('OperationName')
+        self.assertFalse(operation_name.deprecated)
+
+    def test_deprecated_absent(self):
+        service_model = model.ServiceModel(self.model)
+        operation_two = service_model.operation_model('OperationTwo')
+        self.assertFalse(operation_two.deprecated)
+
+
+class TestOperationModelEventStreamTypes(unittest.TestCase):
+    def setUp(self):
+        super(TestOperationModelEventStreamTypes, self).setUp()
+        self.model = {
+            'metadata': {'protocol': 'rest-xml', 'endpointPrefix': 'foo'},
+            'documentation': '',
+            'operations': {
+                'OperationName': {
+                    'http': {
+                        'method': 'POST',
+                        'requestUri': '/',
+                    },
+                    'name': 'OperationName',
+                    'input': {'shape': 'OperationRequest'},
+                    'output': {'shape': 'OperationResponse'},
+                }
+            },
+            'shapes': {
+                'NormalStructure': {
+                    'type': 'structure',
+                    'members': {
+                        'Input': {'shape': 'StringType'}
+                    }
+                },
+                'OperationRequest': {
+                    'type': 'structure',
+                    'members': {
+                        'String': {'shape': 'StringType'},
+                        "Body": {'shape': 'EventStreamStructure'}
+                    },
+                    'payload': 'Body'
+                },
+                'OperationResponse': {
+                    'type': 'structure',
+                    'members': {
+                        'String': {'shape': 'StringType'},
+                        "Body": {'shape': 'EventStreamStructure'}
+                    },
+                    'payload': 'Body'
+                },
+                'StringType': {'type': 'string'},
+                'BlobType': {'type': 'blob'},
+                'EventStreamStructure': {
+                    'eventstream': True,
+                    'type': 'structure',
+                    'members': {
+                        'EventA': {'shape': 'EventAStructure'},
+                        'EventB': {'shape': 'EventBStructure'}
+                    }
+                },
+                'EventAStructure': {
+                    'event': True,
+                    'type': 'structure',
+                    'members': {
+                        'Payload': {
+                            'shape': 'BlobType',
+                            'eventpayload': True
+                        },
+                        'Header': {
+                            'shape': 'StringType',
+                            'eventheader': True
+                        }
+                    }
+                },
+                'EventBStructure': {
+                    'event': True,
+                    'type': 'structure',
+                    'members': {
+                        'Records': {'shape': 'StringType'}
+                    }
+                }
+            }
+        }
+
+    def update_operation(self, **kwargs):
+        operation = self.model['operations']['OperationName']
+        operation.update(kwargs)
+
+    def test_event_stream_input_for_operation(self):
+        service_model = model.ServiceModel(self.model)
+        operation = service_model.operation_model('OperationName')
+        self.assertTrue(operation.has_event_stream_input)
+        event_stream_input = operation.get_event_stream_input()
+        self.assertEqual(event_stream_input.name, 'EventStreamStructure')
+
+    def test_no_event_stream_input_for_operation(self):
+        self.update_operation(input={'shape': 'NormalStructure'})
+        service_model = model.ServiceModel(self.model)
+        operation = service_model.operation_model('OperationName')
+        self.assertFalse(operation.has_event_stream_input)
+        self.assertEqual(operation.get_event_stream_input(), None)
+
+    def test_event_stream_output_for_operation(self):
+        service_model = model.ServiceModel(self.model)
+        operation = service_model.operation_model('OperationName')
+        self.assertTrue(operation.has_event_stream_output)
+        output = operation.get_event_stream_output()
+        self.assertEqual(output.name, 'EventStreamStructure')
+
+    def test_no_event_stream_output_for_operation(self):
+        self.update_operation(output={'shape': 'NormalStructure'})
+        service_model = model.ServiceModel(self.model)
+        operation = service_model.operation_model('OperationName')
+        self.assertFalse(operation.has_event_stream_output)
+        self.assertEqual(operation.get_event_stream_output(), None)
+
+    def test_no_output_shape(self):
+        self.update_operation(output=None)
+        del self.model['operations']['OperationName']['output']
+        service_model = model.ServiceModel(self.model)
+        operation = service_model.operation_model('OperationName')
+        self.assertFalse(operation.has_event_stream_output)
+        self.assertEqual(operation.get_event_stream_output(), None)
+
 
 class TestOperationModelStreamingTypes(unittest.TestCase):
     def setUp(self):
